@@ -4,6 +4,7 @@ import time
 from time import sleep
 import requests
 import urllib3
+import urllib3
 import json
 from dsmigrator.logging import console
 from dsmigrator.api_config import (
@@ -98,7 +99,11 @@ def DirListTenant1(directorylist, url_link_final, tenant1key):
             "Content-Type": "application/json",
         }
         response = requests.request(
-            "GET", url, headers=headers, data=payload, verify=cert
+            "GET",
+            url,
+            headers=headers,
+            data=payload,
+            verify=cert,
         )
         describe = str(response.text)
         alldirectory.append(describe)
@@ -118,7 +123,11 @@ def FileExtensionListTenant1(fileextentionlist, url_link_final, tenant1key):
             "Content-Type": "application/json",
         }
         response = requests.request(
-            "GET", url, headers=headers, data=payload, verify=cert
+            "GET",
+            url,
+            headers=headers,
+            data=payload,
+            verify=cert,
         )
         describe = str(response.text)
         allfileextention.append(describe)
@@ -138,7 +147,11 @@ def FileListTenant1(filelist, url_link_final, tenant1key):
             "Content-Type": "application/json",
         }
         response = requests.request(
-            "GET", url, headers=headers, data=payload, verify=cert
+            "GET",
+            url,
+            headers=headers,
+            data=payload,
+            verify=cert,
         )
         describe = str(response.text)
         allfilelist.append(describe)
@@ -180,7 +193,6 @@ def DirListTenant2(alldirectory, NEW_API_KEY):
         alldirectorynew = validate_create(
             alldirectory, DirectoryListsApiInstance(NEW_API_KEY), "directory"
         )
-        console.log("new directory list")
     console.log(alldirectorynew)
     return alldirectorynew
 
@@ -219,7 +231,13 @@ def PortListGet(url_link_final, tenant1key):
         "api-version": "v1",
         "Content-Type": "application/json",
     }
-    response = requests.request("GET", url, headers=headers, data=payload, verify=cert)
+    response = requests.request(
+        "GET",
+        url,
+        headers=headers,
+        data=payload,
+        verify=cert,
+    )
     describe = str(response.text)
     ports_json = json.loads(describe).get("portLists")
     if ports_json is not None:
@@ -249,7 +267,11 @@ def PortListCreate(t1portlistall, t1portlistname, url_link_final_2, tenant2key):
             "Content-Type": "application/json",
         }
         response = requests.request(
-            "POST", url, headers=headers, data=payload, verify=cert
+            "POST",
+            url,
+            headers=headers,
+            data=payload,
+            verify=cert,
         )
         describe = str(response.text)
         index = describe.find(dirlist)
@@ -272,7 +294,11 @@ def PortListCreate(t1portlistall, t1portlistname, url_link_final_2, tenant2key):
                             "Content-Type": "application/json",
                         }
                         response = requests.request(
-                            "POST", url, headers=headers, data=payload, verify=cert
+                            "POST",
+                            url,
+                            headers=headers,
+                            data=payload,
+                            verify=cert,
                         )
                         t2portlistid.append(str(indexid))
                         console.log("#" + str(count) + " Port List ID:" + indexid)
@@ -285,7 +311,11 @@ def PortListCreate(t1portlistall, t1portlistname, url_link_final_2, tenant2key):
                 "Content-Type": "application/json",
             }
             response = requests.request(
-                "POST", url, headers=headers, data=payload, verify=cert
+                "POST",
+                url,
+                headers=headers,
+                data=payload,
+                verify=cert,
             )
             describe = str(response.text)
             index = describe.find('"ID"')
@@ -319,7 +349,13 @@ def MacListGet(url_link_final, tenant1key):
         "api-version": "v1",
         "Content-Type": "application/json",
     }
-    response = requests.request("GET", url, headers=headers, data=payload, verify=cert)
+    response = requests.request(
+        "GET",
+        url,
+        headers=headers,
+        data=payload,
+        verify=cert,
+    )
     describe = str(response.text)
     mac_json = json.loads(describe).get("macLists")
     if mac_json is not None:
@@ -350,7 +386,11 @@ def MacListCreate(t1maclistall, t1maclistname, url_link_final_2, tenant2key):
             "Content-Type": "application/json",
         }
         response = requests.request(
-            "POST", url, headers=headers, data=payload, verify=cert
+            "POST",
+            url,
+            headers=headers,
+            data=payload,
+            verify=cert,
         )
         describe = str(response.text)
         index = describe.find(dirlist)
@@ -373,7 +413,11 @@ def MacListCreate(t1maclistall, t1maclistname, url_link_final_2, tenant2key):
                             "Content-Type": "application/json",
                         }
                         response = requests.request(
-                            "POST", url, headers=headers, data=payload, verify=cert
+                            "POST",
+                            url,
+                            headers=headers,
+                            data=payload,
+                            verify=cert,
                         )
                         t2maclistid.append(str(indexid))
                         console.log("#" + str(count) + " MAC List ID: " + indexid)
@@ -386,7 +430,11 @@ def MacListCreate(t1maclistall, t1maclistname, url_link_final_2, tenant2key):
                 "Content-Type": "application/json",
             }
             response = requests.request(
-                "POST", url, headers=headers, data=payload, verify=cert
+                "POST",
+                url,
+                headers=headers,
+                data=payload,
+                verify=cert,
             )
             describe = str(response.text)
             index = describe.find('"ID"')
@@ -420,7 +468,13 @@ def IpListGet(url_link_final, tenant1key):
         "api-version": "v1",
         "Content-Type": "application/json",
     }
-    response = requests.request("GET", url, headers=headers, data=payload, verify=cert)
+    response = requests.request(
+        "GET",
+        url,
+        headers=headers,
+        data=payload,
+        verify=cert,
+    )
     describe = str(response.text)
     ip_json = json.loads(describe).get("ipLists")
     if ip_json:
@@ -450,7 +504,11 @@ def IpListCreate(t1iplistall, t1iplistname, url_link_final_2, tenant2key):
             "Content-Type": "application/json",
         }
         response = requests.request(
-            "POST", url, headers=headers, data=payload, verify=cert
+            "POST",
+            url,
+            headers=headers,
+            data=payload,
+            verify=cert,
         )
         describe = str(response.text)
         index = describe.find(dirlist)
@@ -473,7 +531,11 @@ def IpListCreate(t1iplistall, t1iplistname, url_link_final_2, tenant2key):
                             "Content-Type": "application/json",
                         }
                         response = requests.request(
-                            "POST", url, headers=headers, data=payload, verify=cert
+                            "POST",
+                            url,
+                            headers=headers,
+                            data=payload,
+                            verify=cert,
                         )
                         t2iplistid.append(str(indexid))
                         console.log("#" + str(count) + " IP List ID: " + indexid)
@@ -486,7 +548,11 @@ def IpListCreate(t1iplistall, t1iplistname, url_link_final_2, tenant2key):
                 "Content-Type": "application/json",
             }
             response = requests.request(
-                "POST", url, headers=headers, data=payload, verify=cert
+                "POST",
+                url,
+                headers=headers,
+                data=payload,
+                verify=cert,
             )
             describe = str(response.text)
             index = describe.find('"ID"')
@@ -520,7 +586,13 @@ def StatefulGet(url_link_final, tenant1key):
         "api-version": "v1",
         "Content-Type": "application/json",
     }
-    response = requests.request("GET", url, headers=headers, data=payload, verify=cert)
+    response = requests.request(
+        "GET",
+        url,
+        headers=headers,
+        data=payload,
+        verify=cert,
+    )
     describe = str(response.text)
     stateful_json = json.loads(describe).get("statefulConfigurations")
     if stateful_json is not None:
@@ -553,7 +625,11 @@ def StatefulCreate(t1statefulall, t1statefulname, url_link_final_2, tenant2key):
                 "Content-Type": "application/json",
             }
             response = requests.request(
-                "POST", url, headers=headers, data=payload, verify=cert
+                "POST",
+                url,
+                headers=headers,
+                data=payload,
+                verify=cert,
             )
             describe = str(response.text)
             taskjson = json.loads(describe)
@@ -573,7 +649,11 @@ def StatefulCreate(t1statefulall, t1statefulname, url_link_final_2, tenant2key):
                             "Content-Type": "application/json",
                         }
                         response = requests.request(
-                            "POST", url, headers=headers, data=payload, verify=cert
+                            "POST",
+                            url,
+                            headers=headers,
+                            data=payload,
+                            verify=cert,
                         )
                         describe = str(response.text)
                         taskjson1 = json.loads(describe)
@@ -599,7 +679,11 @@ def StatefulCreate(t1statefulall, t1statefulname, url_link_final_2, tenant2key):
                         "Content-Type": "application/json",
                     }
                     response = requests.request(
-                        "POST", url, headers=headers, data=payload, verify=cert
+                        "POST",
+                        url,
+                        headers=headers,
+                        data=payload,
+                        verify=cert,
                     )
                     describe = str(response.text)
                     taskjson = json.loads(describe)
@@ -632,7 +716,13 @@ def ContextGet(url_link_final, tenant1key):
         "api-version": "v1",
         "Content-Type": "application/json",
     }
-    response = requests.request("GET", url, headers=headers, data=payload, verify=cert)
+    response = requests.request(
+        "GET",
+        url,
+        headers=headers,
+        data=payload,
+        verify=cert,
+    )
     describe = str(response.text)
     contexts_json = json.loads(describe).get("contexts")
     if contexts_json is not None:
@@ -665,7 +755,11 @@ def ContextCreate(t1contextall, t1contextname, url_link_final_2, tenant2key):
                 "Content-Type": "application/json",
             }
             response = requests.request(
-                "POST", url, headers=headers, data=payload, verify=cert
+                "POST",
+                url,
+                headers=headers,
+                data=payload,
+                verify=cert,
             )
             describe = str(response.text)
             taskjson = json.loads(describe)
@@ -681,7 +775,11 @@ def ContextCreate(t1contextall, t1contextname, url_link_final_2, tenant2key):
                             "Content-Type": "application/json",
                         }
                         response = requests.request(
-                            "POST", url, headers=headers, data=payload, verify=cert
+                            "POST",
+                            url,
+                            headers=headers,
+                            data=payload,
+                            verify=cert,
                         )
                         describe = str(response.text)
                         taskjson1 = json.loads(describe)
@@ -707,7 +805,11 @@ def ContextCreate(t1contextall, t1contextname, url_link_final_2, tenant2key):
                         "Content-Type": "application/json",
                     }
                     response = requests.request(
-                        "POST", url, headers=headers, data=payload, verify=cert
+                        "POST",
+                        url,
+                        headers=headers,
+                        data=payload,
+                        verify=cert,
                     )
                     describe = str(response.text)
                     taskjson = json.loads(describe)
@@ -737,7 +839,13 @@ def ScheduleGet(url_link_final, tenant1key):
         "api-version": "v1",
         "Content-Type": "application/json",
     }
-    response = requests.request("GET", url, headers=headers, data=payload, verify=cert)
+    response = requests.request(
+        "GET",
+        url,
+        headers=headers,
+        data=payload,
+        verify=cert,
+    )
     describe = str(response.text)
     schedules_json = json.loads(describe).get("schedules")
     if schedules_json is not None:
@@ -770,7 +878,11 @@ def ScheduleCreate(t1scheduleall, t1schedulename, url_link_final_2, tenant2key):
                 "Content-Type": "application/json",
             }
             response = requests.request(
-                "POST", url, headers=headers, data=payload, verify=cert
+                "POST",
+                url,
+                headers=headers,
+                data=payload,
+                verify=cert,
             )
             describe = str(response.text)
             taskjson = json.loads(describe)
@@ -786,7 +898,11 @@ def ScheduleCreate(t1scheduleall, t1schedulename, url_link_final_2, tenant2key):
                             "Content-Type": "application/json",
                         }
                         response = requests.request(
-                            "POST", url, headers=headers, data=payload, verify=cert
+                            "POST",
+                            url,
+                            headers=headers,
+                            data=payload,
+                            verify=cert,
                         )
                         describe = str(response.text)
                         taskjson1 = json.loads(describe)
@@ -812,7 +928,11 @@ def ScheduleCreate(t1scheduleall, t1schedulename, url_link_final_2, tenant2key):
                         "Content-Type": "application/json",
                     }
                     response = requests.request(
-                        "POST", url, headers=headers, data=payload, verify=cert
+                        "POST",
+                        url,
+                        headers=headers,
+                        data=payload,
+                        verify=cert,
                     )
                     describe = str(response.text)
                     taskjson = json.loads(describe)
