@@ -7,12 +7,6 @@ import requests
 import urllib3
 from deepsecurity.rest import ApiException
 
-from rich.logging import RichHandler
-
-# # rich logging
-# class Logging:
-#     def __init__(self):
-
 
 def safe_list_get(l: list, idx: int):
     try:
@@ -106,7 +100,11 @@ def http_search(
             "Content-Type": "application/json",
         }
         response = requests.request(
-            "POST", endpoint, headers=headers, data=payload, verify=cert
+            "POST",
+            endpoint,
+            headers=headers,
+            data=payload,
+            verify=cert,
         )
         describe = str(response.text)
         all_results.append(describe)
